@@ -1,9 +1,6 @@
 package CPAN::Index::API::Role::HavingFilename;
-{
-  $CPAN::Index::API::Role::HavingFilename::VERSION = '0.007';
-}
 
-# ABSTRACT: Provides 'filename' attribute
+our $VERSION = '0.008';
 
 use strict;
 use warnings;
@@ -27,17 +24,13 @@ sub _build_filename {
 
 1;
 
-
-__END__
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-CPAN::Index::API::Role::HavingFilename - Provides 'filename' attribute
-
-=head1 VERSION
-
-version 0.007
+CPAN::Index::Role::HavingFilename - Provides 'filename' attribute
 
 =head1 REQUIRES
 
@@ -53,16 +46,4 @@ of this file relative to the repository root.
 Name of the current file - defaults to the basename of the path specified
 in C<default_location>;
 
-=head1 AUTHOR
-
-Peter Shangov <pshangov@yahoo.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Venda, Inc..
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
-
